{% load i18n %}
<!DOCTYPE html>
<html>
<head>
  <title>{% trans "Your payment is being processed" %}</title>
  <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.1/css/bootstrap.min.css">
  <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.1/css/bootstrap-theme.min.css">
</head>
<body>
  <div class="container">
    {% block content %}
    {% endblock content %}
  </div>
  {% block javascript %}
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/1.11.1/jquery.min.js"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.1/js/bootstrap.min.js"></script>
  {% endblock javascript %}
</body>
</html>
